======================================================================
 `xotl.tools.dim.meta`:mod: -- Meta-definitions for concrete numbers.
======================================================================

.. automodule:: xotl.tools.dim.meta

.. autoclass:: Dimension()
   :members: new

.. autoclass:: Signature

.. autoclass:: Quantity

.. autoclass:: Scalar


.. data:: UNIT

   This the constant value ``1``.  It's given this name to emphasize it's the
   canonical unit for a dimension.


.. data:: SCALAR

   The signature of dimensionless quantities.
